# ImageCrawler: Reddit 

## Purpose

A Crawler for an arbitrary SubReddit of [https://www.reddit.com](https://www.reddit.com)


## Config

### `subreddit`

- the SubReddit to crawl
- type: string
- example: "EarthPorn"
